"""Gradio tool to build themes for the user Interface"""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/99_gradio_themesbuilder.ipynb.

# %% auto 0
__all__ = []

# %% ../../nbs/99_gradio_themesbuilder.ipynb 3
import gradio as gr

# %% ../../nbs/99_gradio_themesbuilder.ipynb 6
gr.themes.builder()
