# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/gradiochat',
                'doc_host': 'https://Hopsakee.github.io',
                'git_url': 'https://github.com/Hopsakee/gradiochat',
                'lib_path': 'src/gradiochat'},
  'syms': { 'gradiochat.app': { 'gradiochat.app.BaseChatApp': ('app.html#basechatapp', 'gradiochat/app.py'),
                                'gradiochat.app.BaseChatApp.__init__': ('app.html#basechatapp.__init__', 'gradiochat/app.py'),
                                'gradiochat.app.BaseChatApp._load_context': ('app.html#basechatapp._load_context', 'gradiochat/app.py'),
                                'gradiochat.app.BaseChatApp.generate_response': ( 'app.html#basechatapp.generate_response',
                                                                                  'gradiochat/app.py'),
                                'gradiochat.app.BaseChatApp.generate_stream': ('app.html#basechatapp.generate_stream', 'gradiochat/app.py'),
                                'gradiochat.app.BaseChatApp.prepare_messages': ( 'app.html#basechatapp.prepare_messages',
                                                                                 'gradiochat/app.py'),
                                'gradiochat.app.HuggingFaceClient': ('app.html#huggingfaceclient', 'gradiochat/app.py'),
                                'gradiochat.app.HuggingFaceClient.__init__': ('app.html#huggingfaceclient.__init__', 'gradiochat/app.py'),
                                'gradiochat.app.HuggingFaceClient.chat_completion': ( 'app.html#huggingfaceclient.chat_completion',
                                                                                      'gradiochat/app.py'),
                                'gradiochat.app.HuggingFaceClient.chat_completion_stream': ( 'app.html#huggingfaceclient.chat_completion_stream',
                                                                                             'gradiochat/app.py'),
                                'gradiochat.app.LLMClientProtocol': ('app.html#llmclientprotocol', 'gradiochat/app.py'),
                                'gradiochat.app.LLMClientProtocol.chat_completion': ( 'app.html#llmclientprotocol.chat_completion',
                                                                                      'gradiochat/app.py'),
                                'gradiochat.app.LLMClientProtocol.chat_completion_stream': ( 'app.html#llmclientprotocol.chat_completion_stream',
                                                                                             'gradiochat/app.py'),
                                'gradiochat.app.TogetherAiClient': ('app.html#togetheraiclient', 'gradiochat/app.py'),
                                'gradiochat.app.TogetherAiClient.__init__': ('app.html#togetheraiclient.__init__', 'gradiochat/app.py'),
                                'gradiochat.app.TogetherAiClient.chat_completion': ( 'app.html#togetheraiclient.chat_completion',
                                                                                     'gradiochat/app.py'),
                                'gradiochat.app.TogetherAiClient.chat_completion_stream': ( 'app.html#togetheraiclient.chat_completion_stream',
                                                                                            'gradiochat/app.py'),
                                'gradiochat.app.create_llm_client': ('app.html#create_llm_client', 'gradiochat/app.py')},
            'gradiochat.config': { 'gradiochat.config.ChatAppConfig': ('config.html#chatappconfig', 'gradiochat/config.py'),
                                   'gradiochat.config.Message': ('config.html#message', 'gradiochat/config.py'),
                                   'gradiochat.config.ModelConfig': ('config.html#modelconfig', 'gradiochat/config.py'),
                                   'gradiochat.config.ModelConfig.api_key': ('config.html#modelconfig.api_key', 'gradiochat/config.py')},
            'gradiochat.gradio_themebuilder': {},
            'gradiochat.gradio_themes': {},
            'gradiochat.ui': { 'gradiochat.ui.GradioChat': ('ui.html#gradiochat', 'gradiochat/ui.py'),
                               'gradiochat.ui.GradioChat.__init__': ('ui.html#gradiochat.__init__', 'gradiochat/ui.py'),
                               'gradiochat.ui.GradioChat.build_interface': ('ui.html#gradiochat.build_interface', 'gradiochat/ui.py'),
                               'gradiochat.ui.GradioChat.respond': ('ui.html#gradiochat.respond', 'gradiochat/ui.py'),
                               'gradiochat.ui.GradioChat.respond_stream': ('ui.html#gradiochat.respond_stream', 'gradiochat/ui.py'),
                               'gradiochat.ui.create_chat_app': ('ui.html#create_chat_app', 'gradiochat/ui.py')},
            'gradiochat.utils': { 'gradiochat.utils._escape_table_cell': ('utils.html#_escape_table_cell', 'gradiochat/utils.py'),
                                  'gradiochat.utils._format_type': ('utils.html#_format_type', 'gradiochat/utils.py'),
                                  'gradiochat.utils.pydantic_to_markdown_table': ( 'utils.html#pydantic_to_markdown_table',
                                                                                   'gradiochat/utils.py')}}}
